
:orphan:

Samtools
========

Automatically generated index page for Samtools:

.. raw:: html

   <ul>

   </ul>
     <a href="samtoolsfaidx.html">
       <p style="margin-bottom: 5px"><b>SamTools: faidx</b> <span style="margin-left: 10px; color: darkgray">SamToolsFaidx</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="samtoolsfaidx.html" style="margin-bottom: 10px">
       v<b>1.9.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="samtoolsflagstat.html">
       <p style="margin-bottom: 5px"><b>SamTools: Flagstat</b> <span style="margin-left: 10px; color: darkgray">SamToolsFlagstat</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="samtoolsflagstat.html" style="margin-bottom: 10px">
       v<b>1.9.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="samtoolsindex.html">
       <p style="margin-bottom: 5px"><b>SamTools: Index</b> <span style="margin-left: 10px; color: darkgray">SamToolsIndex</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="samtoolsindex.html" style="margin-bottom: 10px">
       v<b>1.9.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="samtoolsmpileup.html">
       <p style="margin-bottom: 5px"><b>SamTools: Mpileup</b> <span style="margin-left: 10px; color: darkgray">SamToolsMpileup</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="samtoolsmpileup.html" style="margin-bottom: 10px">
       v<b>1.9.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="samtoolssort.html">
       <p style="margin-bottom: 5px"><b>SamTools: Sort</b> <span style="margin-left: 10px; color: darkgray">SamToolsSort</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="samtoolssort.html" style="margin-bottom: 10px">
       v<b>1.9.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="samtoolsview.html">
       <p style="margin-bottom: 5px"><b>SamTools: View</b> <span style="margin-left: 10px; color: darkgray">SamToolsView</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="samtoolsview.html" style="margin-bottom: 10px">
       v<b>1.9.0</b>
     </a></p>
     </a>
     <hr />
         

